Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(312)

Unified Diff: webrtc/p2p/base/portinterface.h

Issue 2063823008: Adding IceConfig option to assume TURN/TURN candidate pairs will work. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Responding to comments. Doing "presumed writable" determination in Connection. Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/p2p/base/portinterface.h
diff --git a/webrtc/p2p/base/portinterface.h b/webrtc/p2p/base/portinterface.h
index e73861965e538e0ab8e09907d56b63241547c4b7..32b039a23f42f81f218902eb2d5ef364f21c92ca 100644
--- a/webrtc/p2p/base/portinterface.h
+++ b/webrtc/p2p/base/portinterface.h
@@ -66,10 +66,11 @@ class PortInterface {
virtual Connection* GetConnection(
const rtc::SocketAddress& remote_addr) = 0;
// Creates a new connection to the given address.
enum CandidateOrigin { ORIGIN_THIS_PORT, ORIGIN_OTHER_PORT, ORIGIN_MESSAGE };
- virtual Connection* CreateConnection(
- const Candidate& remote_candidate, CandidateOrigin origin) = 0;
+ virtual Connection* CreateConnection(const Candidate& remote_candidate,
+ CandidateOrigin origin,
+ const IceConfig& config) = 0;
// Functions on the underlying socket(s).
virtual int SetOption(rtc::Socket::Option opt, int value) = 0;
@@ -66,10 +66,11 @@ class PortInterface {
virtual Connection* GetConnection(
const rtc::SocketAddress& remote_addr) = 0;
- // Creates a new connection to the given address.
+ // Creates a new connection to the given address with the given ICE config.
enum CandidateOrigin { ORIGIN_THIS_PORT, ORIGIN_OTHER_PORT, ORIGIN_MESSAGE };

Powered by Google App Engine
This is Rietveld 408576698